@@ -1,7 +1,7 @@
 """Flow steps."""
 
 from dataclasses import dataclass
-from typing import Dict, Callable, List
+from typing import Callable, Dict, List
 
 
 @dataclass
