@@ -1,14 +1,12 @@
 """Cluster DBModel."""
 
+from sqlalchemy import Column, String
 
 from blackcap.models.meta.mixins import (
     DBModel,
     SurrogatePKUUID,
     TimestampMixin,
-)  # noqa: E501
-
-
-from sqlalchemy import Column, String
+)
 
 
 class ClusterDB(DBModel, TimestampMixin, SurrogatePKUUID):
