@@ -1,17 +1,14 @@
 """Schedule DBModel."""
 
+from sqlalchemy import Column, DateTime, String
 
 from blackcap.models.meta.mixins import (
     DBModel,
     SurrogatePKUUID,
     TimestampMixin,
-)  # noqa: E501
+)
 from blackcap.models.meta.orm import reference_col
 
-from sqlalchemy import Column, DateTime, String
-
-# from sqlalchemy.orm import relationship
-
 
 class ScheduleDB(DBModel, TimestampMixin, SurrogatePKUUID):
     """Schedule table."""
