@@ -3,7 +3,6 @@
 from abc import ABC, abstractclassmethod
 
 from blackcap.schemas.api.schedule.post import ScheduleCreate
-from blackcap.schemas.schedule import Schedule
 
 
 class BaseScheduler(ABC):
@@ -18,13 +17,13 @@ class BaseScheduler(ABC):
     @abstractclassmethod
     def schedule(
         self: "BaseScheduler", schedule_create: ScheduleCreate
-    ) -> Schedule:  # noqa: E501
+    ) -> ScheduleCreate:
         """Create schedule from schedule request.
 
         Args:
             schedule_create (ScheduleCreate): Schedule create request
 
         Returns:
-            Schedule: Instance of Schedule
+            ScheduleCreate: Instance of Schedule
         """
-        pass
+        return ScheduleCreate()
